pub(crate) struct SectionsExpanded(BTreeSet<SidebarSectionName>);Expand description
The sections that are expanded.
Tuple Fields
0: BTreeSet<SidebarSectionName>Implementations
Sourceimpl SectionsExpanded
impl SectionsExpanded
Sourcepub(crate) fn is_section_expanded(
&self,
section_name: SidebarSectionName,
) -> bool
pub(crate) fn is_section_expanded( &self, section_name: SidebarSectionName, ) -> bool
Whether the section with the given name is expanded.
Sourcepub(crate) fn set_section_expanded(
&mut self,
section_name: SidebarSectionName,
expanded: bool,
)
pub(crate) fn set_section_expanded( &mut self, section_name: SidebarSectionName, expanded: bool, )
Set whether the section with the given name is expanded.