#[repr(transparent)]pub struct SessionSettings {
inner: TypedObjectRef<SessionSettings, ()>,
phantom: PhantomData<()>,
}Expand description
The settings of a Session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SessionSettings, ()>phantom: PhantomData<()>Implementations
Sourceimpl SessionSettings
impl SessionSettings
Sourcepub fn session_id(&self) -> <OnceCell<String> as Property>::Value
pub fn session_id(&self) -> <OnceCell<String> as Property>::Value
The ID of the session these settings are for.
Sourcepub fn notifications_enabled(&self) -> <PhantomData<bool> as Property>::Value
pub fn notifications_enabled(&self) -> <PhantomData<bool> as Property>::Value
Whether notifications are enabled for this session.
Sourcepub fn set_notifications_enabled<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_notifications_enabled<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether notifications are enabled for this session.
Sourcepub fn public_read_receipts_enabled(
&self,
) -> <PhantomData<bool> as Property>::Value
pub fn public_read_receipts_enabled( &self, ) -> <PhantomData<bool> as Property>::Value
Whether public read receipts are enabled for this session.
Sourcepub fn set_public_read_receipts_enabled<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_public_read_receipts_enabled<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether public read receipts are enabled for this session.
Sourcepub fn typing_enabled(&self) -> <PhantomData<bool> as Property>::Value
pub fn typing_enabled(&self) -> <PhantomData<bool> as Property>::Value
Whether typing notifications are enabled for this session.
Sourcepub fn set_typing_enabled<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_typing_enabled<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether typing notifications are enabled for this session.
Sourcepub fn connect_session_id_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_id_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session-id property
Sourcepub fn connect_notifications_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_notifications_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the notifications-enabled property
Sourcepub fn connect_public_read_receipts_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_public_read_receipts_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the public-read-receipts-enabled property
Sourcepub fn connect_typing_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_typing_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the typing-enabled property
Sourcepub fn notify_session_id(&self)
pub fn notify_session_id(&self)
Notify listeners of a change in the session-id property
Sourcepub fn notify_notifications_enabled(&self)
pub fn notify_notifications_enabled(&self)
Notify listeners of a change in the notifications-enabled property
Sourcepub fn notify_public_read_receipts_enabled(&self)
pub fn notify_public_read_receipts_enabled(&self)
Notify listeners of a change in the public-read-receipts-enabled property
Sourcepub fn notify_typing_enabled(&self)
pub fn notify_typing_enabled(&self)
Notify listeners of a change in the typing-enabled property
Sourceimpl SessionSettings
impl SessionSettings
Sourcepub(crate) fn new(session_id: &str) -> Self
pub(crate) fn new(session_id: &str) -> Self
Create a new SessionSettings for the given session ID.
Sourcepub(crate) fn restore(
session_id: &str,
stored_settings: StoredSessionSettings,
) -> Self
pub(crate) fn restore( session_id: &str, stored_settings: StoredSessionSettings, ) -> Self
Restore existing SessionSettings with the given session ID and stored
settings.
Sourcepub(crate) fn stored_settings(&self) -> StoredSessionSettings
pub(crate) fn stored_settings(&self) -> StoredSessionSettings
The stored settings.
Sourcepub(crate) fn apply_version_1_migration(&self)
pub(crate) fn apply_version_1_migration(&self)
Apply the migration of the stored settings from version 0 to version 1.
Sourcepub(crate) fn explore_custom_servers(&self) -> IndexSet<OwnedServerName>
pub(crate) fn explore_custom_servers(&self) -> IndexSet<OwnedServerName>
Custom servers to explore.
Sourcepub(crate) fn set_explore_custom_servers(
&self,
servers: IndexSet<OwnedServerName>,
)
pub(crate) fn set_explore_custom_servers( &self, servers: IndexSet<OwnedServerName>, )
Set the custom servers to explore.
Sourcepub(crate) fn is_section_expanded(
&self,
section_name: SidebarSectionName,
) -> bool
pub(crate) fn is_section_expanded( &self, section_name: SidebarSectionName, ) -> bool
Whether the section with the given name is expanded.
Sourcepub(crate) fn set_section_expanded(
&self,
section_name: SidebarSectionName,
expanded: bool,
)
pub(crate) fn set_section_expanded( &self, section_name: SidebarSectionName, expanded: bool, )
Set whether the section with the given name is expanded.